# Installation


It is recommended, but not required, that you use a virtual environment:
```bash
python -m venv .env
```
```bash
source .env/bin/active
```

Install SQLMesh using `pip`:
```bash
pip install sqlmesh
```

## Next steps
* [Jump right in with the quickstart](quick_start.md)
